@@ -36,11 +36,13 @@
 #ifndef __AS_VERSION_H
 #define __AS_VERSION_H
 
+#include <glib.h>
+
 /* compile time version
  */
-#define AS_MAJOR_VERSION				(0)
-#define AS_MINOR_VERSION				(6)
-#define AS_MICRO_VERSION				(5)
+#define AS_MAJOR_VERSION				0
+#define AS_MINOR_VERSION				7
+#define AS_MICRO_VERSION				10
 
 /* check whether a As version equal to or greater than
  * major.minor.micro.
@@ -51,4 +53,6 @@
      (AS_MAJOR_VERSION == (major) && AS_MINOR_VERSION == (minor) && \
       AS_MICRO_VERSION >= (micro)))
 
+const gchar	*as_version_string			(void);
+
 #endif /* __AS_VERSION_H */
